summary refs log tree commit diff
path: root/pkgs/development/go-modules
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/go-modules')
-rw-r--r--pkgs/development/go-modules/generic/default.nix7
1 files changed, 4 insertions, 3 deletions
diff --git a/pkgs/development/go-modules/generic/default.nix b/pkgs/development/go-modules/generic/default.nix
index a7852bcc7e5..3b645f9ce8b 100644
--- a/pkgs/development/go-modules/generic/default.nix
+++ b/pkgs/development/go-modules/generic/default.nix
@@ -46,8 +46,9 @@
 # Not needed with buildGoModule
 , goPackagePath ? ""
 
 # needed for buildFlags warning
 , buildFlags ? ""
+, buildFlagsArray ? ""
 
 , ... }@args':
 
@@ -271,6 +272,6 @@ let
     };
   });
 in
-lib.warnIf (buildFlags != "")
-  "Use the `ldflags` and/or `tags` attributes instead of `buildFlags`"
+lib.warnIf (buildFlags != "" || buildFlagsArray != "")
+  "Use the `ldflags` and/or `tags` attributes instead of `buildFlags`/`buildFlagsArray`"
   package
@@ -46,8 +46,9 @@
 , goPackagePath ? ""
 
-# needed for buildFlags warning
+# needed for buildFlags{,Array} warning
 , buildFlags ? ""